@@ -1,12 +1,12 @@
 /////////////////////////////////////////////////////////////
 //                                                         //
-// Copyright (c) 2007-2014 by The University of Queensland //
+// Copyright (c) 2007-2017 by The University of Queensland //
 // Centre for Geoscience Computing                         //
 // http://earth.uq.edu.au/centre-geoscience-computing      //
 //                                                         //
 // Primary Business: Brisbane, Queensland, Australia       //
 // Licensed under the Open Software License version 3.0    //
-// http://www.opensource.org/licenses/osl-3.0.php          //
+// http://www.apache.org/licenses/LICENSE-2.0              //
 //                                                         //
 /////////////////////////////////////////////////////////////
 
@@ -35,7 +35,7 @@ class Line2D : public AGeometricObject
   Line2D();
   Line2D(const Vector3&,const Vector3&);
 
-  Vector3 intersect(const Line2D&);
+  Vector3 intersect(const Line2D&) const;
   Line2D parallel(double);
   virtual double getDist(const Vector3&) const;
   Vector3 getOrig() const {return m_p1;};
