@@ -1,12 +1,12 @@
 /////////////////////////////////////////////////////////////
 //                                                         //
-// Copyright (c) 2007-2014 by The University of Queensland //
+// Copyright (c) 2007-2017 by The University of Queensland //
 // Centre for Geoscience Computing                         //
 // http://earth.uq.edu.au/centre-geoscience-computing      //
 //                                                         //
 // Primary Business: Brisbane, Queensland, Australia       //
 // Licensed under the Open Software License version 3.0    //
-// http://www.opensource.org/licenses/osl-3.0.php          //
+// http://www.apache.org/licenses/LICENSE-2.0              //
 //                                                         //
 /////////////////////////////////////////////////////////////
 
@@ -414,8 +414,8 @@ void MNTable2D::tagParticlesNear(const Vector3& p,double dist,int gid, int tag)
 */
 void MNTable2D::tagParticlesInVolume(const AVolume& V,int tag,unsigned int gid)
 {
-  for(int i=0;i<m_nx-1;i++){
-    for(int j=0;j<m_ny-1;j++){
+  for(int i=0;i<m_nx;i++){
+    for(int j=0;j<m_ny;j++){
       vector<Sphere*> vs=m_data[idx(i,j)].getSpheresInVolume(&V,gid);
       for(vector<Sphere*>::iterator iter=vs.begin();
 	  iter!=vs.end();
